==> beagle-0.0.11.tar.gz: beagle-0.0.11/Filters/FilterJava.cs <==
//
// FilterJava.cs
//
// Copyright (C) 2004 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//


using System;
using System.Collections;
using System.IO;
using System.Text;
namespace Beagle.Filters {

	public class FilterJava : FilterSource {

		static string [] strKeyWords = {"abstract", "boolean", "break", "byte", "case", "catch",
						 "char", "class", "const", "continue", "default", "do",
						 "double", "else", "extends", "final", "finally", "float", 
						 "for", "goto", "if", "implements", "import", "instanceof", 
						 "int", "interface", "long", "native", "new", "package", 
						 "private", "protected", "public", "return", "short", "static", 
						 "strictfp", "super", "switch", "synchronized", "this", "throw",
						 "throws", "transient", "try", "void", "volatile", "while" };
		
		public FilterJava ()
		{
			AddSupportedMimeType ("text/x-java");

		}

		override protected void DoOpen (FileInfo info)
		{
			foreach (string keyword in strKeyWords)
				KeyWordsHash [keyword] = true;
			SrcLangType = LangType.C_Style;
		}

		override protected void DoPull ()
		{
			string str = TextReader.ReadLine ();
			if (str == null)
				Finished ();
			else
				ExtractTokens (str);
		}
	}
}

==> beagle_0.2.12.orig.tar.gz: beagle-0.2.12/Filters/FilterJava.cs <==
//
// FilterJava.cs
//
// Copyright (C) 2004 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections;
using System.IO;
using System.Text;

using Beagle.Daemon;

namespace Beagle.Filters {

	public class FilterJava : FilterSource {

		static string [] strKeyWords = {"abstract", "boolean", "break", "byte", "case", "catch",
						 "char", "class", "const", "continue", "default", "do",
						 "double", "else", "extends", "final", "finally", "float", 
						 "for", "goto", "if", "implements", "import", "instanceof", 
						 "int", "interface", "long", "native", "new", "package", 
						 "private", "protected", "public", "return", "short", "static", 
						 "strictfp", "super", "switch", "synchronized", "this", "throw",
						 "throws", "transient", "try", "void", "volatile", "while" };
		
		public FilterJava ()
		{
			AddSupportedFlavor (FilterFlavor.NewFromMimeType ("text/x-java"));

		}

		override protected void DoOpen (FileInfo info)
		{
			foreach (string keyword in strKeyWords)
				KeyWordsHash [keyword] = true;
			SrcLangType = LangType.C_Style;
		}

		override protected void DoPull ()
		{
			string str = TextReader.ReadLine ();
			if (str == null)
				Finished ();
			else
				ExtractTokens (str);
		}
	}
}
